@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_tout_compris' => 'حجب كل رسائل الرفيق',
@@ -79,5 +75,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// T
 	'titre_compagnon' => 'الرفيق',
-	'titre_page_configurer_compagnon' => 'إعداد الرفيق'
-);
+	'titre_page_configurer_compagnon' => 'إعداد الرفيق',
+];
