@@ -1,13 +1,10 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/dist.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dist_description' => 'Jeu de squelettes distribué avec SPIP 3.',
-	'dist_slogan' => 'Squelettes par défaut de SPIP 3'
-);
+	'dist_slogan' => 'Squelettes par défaut de SPIP 3',
+];
